pecos.error\_models.depolarizing\_error\_model
==============================================

.. automodule:: pecos.error_models.depolarizing_error_model











   .. rubric:: Classes

   .. autosummary::

      DepolarizingErrorModel
